@@ -26,7 +26,8 @@ DEFAULT_TIMEOUT = 10
 __all__ = ['Error', 'Response', 'BaseAPI', 'API', 'Auth', 'Users', 'Groups',
            'Channels', 'Chat', 'IM', 'IncomingWebhook', 'Search', 'Files',
            'Stars', 'Emoji', 'Presence', 'RTM', 'Team', 'Reactions', 'Pins',
-           'UserGroups', 'UserGroupsUsers', 'MPIM', 'OAuth', 'Slacker']
+           'UserGroups', 'UserGroupsUsers', 'MPIM', 'OAuth', 'DND',
+           'FilesComments', 'Slacker']
 
 
 class Error(Exception):
@@ -96,7 +97,6 @@ class Users(BaseAPI):
         return self.get('users.getPresence', params={'user': user})
 
     def set_presence(self, presence):
-        assert presence in Presence.TYPES, 'Invalid presence type'
         return self.post('users.setPresence', data={'presence': presence})
 
     def get_user_id(self, user_name):
@@ -180,14 +180,15 @@ class Channels(BaseAPI):
                         params={'exclude_archived': exclude_archived})
 
     def history(self, channel, latest=None, oldest=None, count=None,
-                inclusive=None):
+                inclusive=False, unreads=False):
         return self.get('channels.history',
                         params={
                             'channel': channel,
                             'latest': latest,
                             'oldest': oldest,
                             'count': count,
-                            'inclusive': inclusive
+                            'inclusive': int(inclusive),
+                            'unreads': int(unreads)
                         })
 
     def mark(self, channel, ts):
@@ -236,7 +237,7 @@ class Chat(BaseAPI):
                      parse=None, link_names=None, attachments=None,
                      unfurl_links=None, unfurl_media=None, icon_url=None,
                      icon_emoji=None):
-       
+
         # Ensure attachments are json encoded
         if attachments:
             if isinstance(attachments, list):
@@ -257,9 +258,21 @@ class Chat(BaseAPI):
                              'icon_emoji': icon_emoji
                          })
 
-    def update(self, channel, ts, text):
+    def update(self, channel, ts, text, attachments=None, parse=None,
+               link_names=False, as_user=None):
+        # Ensure attachments are json encoded
+        if attachments and isinstance(attachments, list):
+            attachments = json.dumps(attachments)
         return self.post('chat.update',
-                         data={'channel': channel, 'ts': ts, 'text': text})
+                         data={
+                             'channel': channel,
+                             'ts': ts,
+                             'text': text,
+                             'attachments': attachments,
+                             'parse': None,
+                             'link_names': int(link_names),
+                             'as_user': as_user,
+                         })
 
     def delete(self, channel, ts):
         return self.post('chat.delete', data={'channel': channel, 'ts': ts})
@@ -357,7 +370,29 @@ class Search(BaseAPI):
                         })
 
 
+class FilesComments(BaseAPI):
+    def add(self, file_, comment):
+        return self.post('files.comments.add',
+                         data={'file': file_, 'comment': comment})
+
+    def delete(self, file_, id):
+        return self.post('files.comments.delete',
+                         data={'file': file_, 'id': id})
+
+    def edit(self, file_, id, comment):
+        return self.post('files.comments.edit',
+                         data={'file': file, 'id': id, 'comment': comment})
+
+
 class Files(BaseAPI):
+    def __init__(self, *args, **kwargs):
+        super(Files, self).__init__(*args, **kwargs)
+        self._comments = FilesComments(*args, **kwargs)
+
+    @property
+    def comments(self):
+        return self._comments
+
     def list(self, user=None, ts_from=None, ts_to=None, types=None,
              count=None, page=None):
         return self.get('files.list',
@@ -394,11 +429,39 @@ class Files(BaseAPI):
     def delete(self, file_):
         return self.post('files.delete', data={'file': file_})
 
+    def revoke_public_url(self, file_):
+        return self.post('files.revokePublicURL', data={'file': file_})
+
+    def shared_public_url(self, file_):
+        return self.post('files.sharedPublicURL', data={'file': file_})
+
 
 class Stars(BaseAPI):
+    def add(self, file_=None, file_comment=None, channel=None, timestamp=None):
+        assert file_ or file_comment or channel
+
+        return self.post('stars.add',
+                         data={
+                             'file': file_,
+                             'file_comment': file_comment,
+                             'channel': channel,
+                             'timestamp': timestamp
+                         })
+    
     def list(self, user=None, count=None, page=None):
         return self.get('stars.list',
                         params={'user': user, 'count': count, 'page': page})
+    
+    def remove(self, file_=None, file_comment=None, channel=None, timestamp=None):
+        assert file_ or file_comment or channel
+
+        return self.post('stars.remove',
+                         data={
+                             'file': file_,
+                             'file_comment': file_comment,
+                             'channel': channel,
+                             'timestamp': timestamp
+                         })
 
 
 class Emoji(BaseAPI):
@@ -417,8 +480,13 @@ class Presence(BaseAPI):
 
 
 class RTM(BaseAPI):
-    def start(self):
-        return self.get('rtm.start')
+    def start(self, simple_latest=False, no_unreads=False, mpim_aware=False):
+        return self.get('rtm.start',
+                        params={
+                            'simple_latest': int(simple_latest),
+                            'no_unreads': int(no_unreads),
+                            'mpim_aware': int(mpim_aware),
+                        })
 
 
 class Team(BaseAPI):
@@ -429,6 +497,18 @@ class Team(BaseAPI):
         return self.get('team.accessLogs',
                         params={'count': count, 'page': page})
 
+    def integration_logs(self, service_id=None, app_id=None, user=None,
+                         change_type=None, count=None, page=None):
+        return self.get('team.integrationLogs',
+                        params={
+                            'service_id': service_id,
+                            'app_id': app_id,
+                            'user': user,
+                            'change_type': change_type,
+                            'count': count,
+                            'page': page,
+                        })
+
 
 class Reactions(BaseAPI):
     def add(self, name, file_=None, file_comment=None, channel=None,
@@ -612,6 +692,26 @@ class UserGroups(BaseAPI):
         })
 
 
+class DND(BaseAPI):
+    def team_info(self, users=None):
+        if isinstance(users, (tuple, list)):
+            users = ','.join(users)
+
+        return self.get('dnd.teamInfo', params={'users': users})
+
+    def set_snooze(self, num_minutes):
+        return self.post('dnd.setSnooze', data={'num_minutes': num_minutes})
+
+    def info(self, user=None):
+        return self.get('dnd.info', params={'user': user})
+
+    def end_dnd(self):
+        return self.post('dnd.endDnd')
+
+    def end_snooze(self):
+        return self.post('dnd.endSnooze')
+
+
 class OAuth(BaseAPI):
     def access(self, client_id, client_secret, code, redirect_uri=None):
         return self.post('oauth.access',
@@ -647,6 +747,7 @@ class Slacker(object):
                  timeout=DEFAULT_TIMEOUT):
         self.im = IM(token=token, timeout=timeout)
         self.api = API(token=token, timeout=timeout)
+        self.dnd = DND(token=token, timeout=timeout)
         self.rtm = RTM(token=token, timeout=timeout)
         self.auth = Auth(token=token, timeout=timeout)
         self.chat = Chat(token=token, timeout=timeout)
